#!/usr/bin/env node
/*!
 * gitmars v4.0.0-alpha.9
 * 这是一个git工作流工具
 * (c) 2021-2022 saqqdy<https://github.com/saqqdy> 
 * Released under the MIT License.
 */
import { program } from 'commander';
import sh from 'shelljs';
import chalk from 'chalk';
import { queue } from '@gitmars/core/lib/queue';
import getIsGitProject from '@gitmars/core/lib/git/getIsGitProject';
import getCurrentBranch from '@gitmars/core/lib/git/getCurrentBranch';
import getStashList from '@gitmars/core/lib/git/getStashList';
import { createArgs } from '@gitmars/core/lib/utils/command';
import getConfig from '#lib/conf/get';
import i18n from '#lib/locales/index';

const { red, yellow } = chalk;
const { args, options } = getConfig;
if (!getIsGitProject()) {
  sh.echo(
    red(i18n.__("The current directory is not a git project directory"))
  );
  process.exit(1);
}
program.name("gitm get").usage("[message] [index] [-k --keep [keep]]").description(i18n.__("Restore staging area file"));
if (args.length > 0)
  program.arguments(createArgs(args));
options.forEach((o) => {
  program.option(o.flags, o.description, o.defaultValue);
});
program.action((message, index, opt) => {
  if (!message)
    message = getCurrentBranch();
  const list = getStashList(message);
  if (list.length === 0) {
    sh.echo(yellow(i18n.__("There are no files staged in this branch!")));
    process.exit(0);
  }
  if (index === void 0 && list.length > 1) {
    sh.echo(
      yellow(`\u8BE5\u5206\u652F\u4E0B\u6709${list.length}\u6761\u6682\u5B58\u8BB0\u5F55\uFF0C\u9ED8\u8BA4\u6062\u590D\u6700\u8FD1\u7684\u4E00\u6761\u8BB0\u5F55`)
    );
  }
  if (list.length > 2) {
    sh.echo(
      yellow(
        `\u8BE5\u5206\u652F\u4E0B\u6709${list.length}\u6761\u6682\u5B58\u8BB0\u5F55\uFF0C\u5EFA\u8BAE\u5B9A\u671F\u6E05\u7406\u4E0D\u5FC5\u8981\u7684\u6682\u5B58\u8BB0\u5F55\uFF01`
      )
    );
  }
  queue([
    {
      cmd: `git stash ${opt.keep ? "apply" : "pop"} ${list[index || 0].key}`,
      config: {
        again: opt.keep ? false : `git stash drop ${list[index || 0].key}`,
        success: i18n.__("File recovery successful"),
        fail: i18n.__("Recovery failed, please check for conflicts")
      }
    },
    "git reset -q HEAD -- ."
  ]);
});
program.parse(process.argv);
