#!/usr/bin/env node
/*!
 * gitmars v4.0.0-alpha.9
 * 这是一个git工作流工具
 * (c) 2021-2022 saqqdy<https://github.com/saqqdy> 
 * Released under the MIT License.
 */
import { program } from 'commander';
import sh from 'shelljs';
import { createArgs } from '@gitmars/core/lib/utils/command';
import { spawnSync } from '@gitmars/core/lib/spawn';
import linkConfig from '#lib/conf/link';
import i18n from '#lib/locales/index';

const { args, options } = linkConfig;
program.name("gitm link").usage("[name]").description(i18n.__("Link local package"));
if (args.length > 0)
  program.arguments(createArgs(args));
options.forEach((o) => {
  program.option(o.flags, o.description, o.defaultValue);
});
program.action((name) => {
  const isLink = sh.test("-L", `./node_modules/${name}`);
  const isExist = sh.test("-e", `./node_modules/${name}`);
  const npmClient = sh.which("yarn") ? "yarn" : "npm";
  if (!name) {
    const { status: status2 } = spawnSync(npmClient, ["link"]);
    if (status2 === 0)
      sh.echo(i18n.__("Processing completed"));
    else
      sh.echo(i18n.__("There was an error"));
    process.exit(0);
  } else if (isLink) {
    sh.rm("-rf", `./node_modules/${name}`);
  } else if (isExist) {
    sh.mv(`./node_modules/${name}`, `./node_modules/${name}_bak`);
  }
  const { status } = spawnSync(npmClient, ["link", name]);
  if (status === 0)
    sh.echo(i18n.__("Processing completed"));
  else {
    sh.echo(
      `\u5904\u7406\u5931\u8D25\uFF0C${name}\u8F6F\u94FE\u4E0D\u5B58\u5728\uFF0C\u8BF7\u8FDB\u5165\u672C\u5730${name}\u6839\u76EE\u5F55\u6267\u884C\uFF1Agitm link`
    );
  }
});
program.parse(process.argv);
