#!/usr/bin/env node
/*!
 * gitmars v4.0.0-alpha.9
 * 这是一个git工作流工具
 * (c) 2021-2022 saqqdy<https://github.com/saqqdy> 
 * Released under the MIT License.
 */
import { program } from 'commander';
import sh from 'shelljs';
import chalk from 'chalk';
import { queue } from '@gitmars/core/lib/queue';
import getIsGitProject from '@gitmars/core/lib/git/getIsGitProject';
import { createArgs } from '@gitmars/core/lib/utils/command';
import revertConfig from '#lib/conf/revert';
import i18n from '#lib/locales/index';

const { red, yellow } = chalk;
const { args, options } = revertConfig;
if (!getIsGitProject()) {
  sh.echo(
    red(i18n.__("The current directory is not a git project directory"))
  );
  process.exit(1);
}
program.name("gitm revert").usage("[commitid] [-n --number [number]] [-m --mode [mode]]").description(i18n.__("Undo a commit record"));
if (args.length > 0)
  program.arguments(createArgs(args));
options.forEach((o) => {
  program.option(o.flags, o.description, o.defaultValue);
});
program.action((commitid, opt) => {
  const cmd = [];
  let n = "HEAD", m = "";
  if (opt.mode)
    m = " -m " + Math.abs(Number(opt.mode));
  if (opt.number) {
    const num = Math.abs(Number(opt.number));
    if (num > 1)
      n += "~" + (num - 1);
    cmd.push({
      cmd: `git revert ${n}${m}`,
      config: {
        again: true,
        success: i18n.__("Successfully reverted"),
        fail: i18n.__(
          "An error has occurred, please follow the instructions"
        )
      }
    });
  } else if (commitid) {
    cmd.push({
      cmd: `git revert ${commitid}${m}`,
      config: {
        again: true,
        success: i18n.__("Successfully reverted"),
        fail: i18n.__(
          "An error has occurred, please follow the instructions"
        )
      }
    });
  } else {
    sh.echo(yellow(i18n.__("Commands do not meet the specifications")));
    process.exit(1);
  }
  queue(cmd);
});
program.parse(process.argv);
